@@ -19,6 +19,8 @@
 Module for the ComposeXSettings class
 """
 
+import re
+from os import environ
 from datetime import datetime as dt
 from json import dumps
 from copy import deepcopy
@@ -40,6 +42,7 @@ from ecs_composex.utils.init_ecs import set_ecs_settings
 from ecs_composex.utils.init_s3 import create_bucket
 from ecs_composex.ecs.ecs_service_config import set_service_ports
 from cfn_flip.yaml_dumper import LongCleanDumper
+from ecs_composex.secrets.secrets_config import parse_secrets
 
 
 def render_services_ports(services):
@@ -75,14 +78,33 @@ def merge_ports(source_ports, new_ports):
     return new_ports
 
 
+def parse_environment_variables(key):
+    """
+    Method to go over the content and interpolate possibly existing environment variables.
+
+    :param str key: the key to find the value for in environment
+    :return: env_key
+    :rtype: str
+    :raises: EnvironmentError
+    """
+    strip_re = re.compile(r"([^\${}]+)")
+    env_key = strip_re.findall(key)[0]
+    LOG.debug(f"Key {key} gives {env_key}")
+    if environ.get(env_key):
+        return environ.get(env_key)
+    raise EnvironmentError(f"Key {key} not found in environment variables.")
+
+
 def merge_service_definition(original_def, override_def, nested=False):
     """
     Merges two services definitions if service exists in both compose files.
 
+    :param bool nested:
     :param dict original_def:
     :param dict override_def:
     :return:
     """
+
     if not nested:
         original_def = deepcopy(original_def)
     for key in override_def.keys():
@@ -114,6 +136,23 @@ def merge_service_definition(original_def, override_def, nested=False):
     return original_def
 
 
+def interpolate_env_vars(content):
+    """
+    Function to interpolate env vars from content
+
+    :param dict content:
+    :return:
+    """
+    env_var_regex = re.compile(r"^\$\{[\w\d-]+\}$")
+    if not content:
+        return
+    for key in content.keys():
+        if isinstance(content[key], dict):
+            interpolate_env_vars(content[key])
+        elif isinstance(content[key], str) and env_var_regex.match(content[key]):
+            content[key] = parse_environment_variables(content[key])
+
+
 def merge_config_file(original_content, override_content):
     """
     Function to merge two docker compose files content.
@@ -150,7 +189,6 @@ def merge_config_file(original_content, override_content):
             )
     original_content.update(override_content)
     original_content["services"] = original_services
-    return original_content
 
 
 class ComposeXSettings(object):
@@ -280,16 +318,19 @@ class ComposeXSettings(object):
             self.compose_content = load_composex_file(kwargs[self.input_file_arg][0])
         elif content is None and len(kwargs[self.input_file_arg]) > 1:
             files_list = kwargs[self.input_file_arg]
-            source_content = load_composex_file(files_list[0])
+            self.compose_content = load_composex_file(files_list[0])
             files_list.pop(0)
             for file in files_list:
-                self.compose_content = merge_config_file(
-                    source_content, load_composex_file(file)
-                )
+                merge_config_file(self.compose_content, load_composex_file(file))
+                LOG.debug(yaml.dump(self.compose_content))
+
         elif content and isinstance(content, dict):
             self.compose_content = content
         if keyisset("services", self.compose_content):
             render_services_ports(self.compose_content["services"])
+        LOG.debug(yaml.dump(self.compose_content))
+        interpolate_env_vars(self.compose_content)
+        parse_secrets(self)
 
     def parse_command(self, kwargs, content=None):
         """
